The GPS-TCX data as a formated data.table
Arguments
- tcx_file
a character string specifying the path to a TCX file exported from the Fitbit app or website. TCX (Training Center XML) files can be exported from the Fitbit website under account settings or from the Fitbit app by sharing a specific activity.
- time_zone
a character string specifying the time zone parameter ('tz') as is defined in the 'lubridate::ymd_hms()' function
- verbose
a boolean. If TRUE then information will be printed out in the console